@@ -114,6 +114,9 @@ current file, collecting Devel::CoverX::Covered information.
 
 B<Edit - Copy Package Name> -- C<C-o e c p> -- Copy the current package name.
 
+B<Edit - Copy Package Name From File> -- C<C-o e c P> -- Copy the
+current package name from file name.
+
 B<Edit - Copy Sub Name> -- C<C-o e c s> -- Copy the current sub name.
 
 B<Edit - Copy File Name> -- C<C-o e c f> -- Copy the current file name.
@@ -1225,7 +1228,18 @@ restucture the code.
 =head3 Edit - Copy Package Name
 
 C<C-o e c p> -- Copy the current package statement name to the
-clipboard (kill-ring) and display it in the echo area.
+clipboard (kill-ring) and display it in the echo area. If there is no
+package statement, try to get the package name from the file name.
+
+
+
+=head3 Edit - Copy Package Name From File Name
+
+C<C-o e c P> -- Assuming the file is a Perl module in a lib directory,
+copy the corrsponding package name to the clipboard (kill-ring) and
+display it in the echo area.
+
+Useful when you've just created an empty new Perl module .pm file.
 
 
 
@@ -1891,7 +1905,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense;
-$Devel::PerlySense::VERSION = '0.0216';
+$Devel::PerlySense::VERSION = '0.0217';
 
 
 use Spiffy -Base;
@@ -2166,6 +2180,9 @@ Currently supported:
   $self->method, look in current file and base classes. If no sub can
   be found, look for POD.
 
+  shift->method for subs that don't have a $self. Same as
+  $self->method.
+
   $object->method, look in current file and used modules. If no sub
   can be found, look for POD.
 
