@@ -33,7 +33,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Document;
-$Devel::PerlySense::Document::VERSION = '0.0216';
+$Devel::PerlySense::Document::VERSION = '0.0217';
 
 
 
@@ -428,6 +428,8 @@ sub methodCallAt {
 
 Return the name of the $self->method at $row, $col in this document.
 
+Also matches shift->method, if there is no $self in this sub at all.
+
 If no method call is found, maybe warn and return undef.
 
 Die on errors.
@@ -438,14 +440,40 @@ sub selfMethodCallAt {
 
     my ($object, $method) = $self->methodCallAt(row => $row, col => $col);
     $method or return(undef);
-    $object and $object eq '$self' or return(undef);    #We only know about self so far
+    $object or return(undef);
+    $object eq '$self' and return($method);
 
-    return($method);
+    # If the object is "shift" and there is no mention of a $self in
+    # the sub, assume it's $self being shifted off @_
+    if($object eq "shift") {
+        $self->isThereSelfInSubAt(row => $row, col => $col) and return undef;
+        return($method);
+    }
+
+    return(undef);
 }
 
+=head2 isThereSelfInSubAt(row => $row, col => $col) : Bool
 
+Whether there is a mention of $self in the sub surrounding $row, $col.
 
+=cut
+sub isThereSelfInSubAt {
+    my ($row, $col) = Devel::PerlySense::Util::aNamedArg(["row", "col"], @_);
 
+    my $oLocationSubAt = $self->oLocationSubAt(row => $row, col => $col)
+        or return(0);
+
+    my $source = $oLocationSubAt->rhProperty->{source} or return(0);
+
+    if ( $source =~ / \$self \b /smx ) {
+        # There is a $self somewhere in this sub (could be false
+        # positive in a comment or string), so shift isn't $self
+        return(1);
+    }
+
+    return(0);
+}
 
 =head2 moduleMethodCallAt(row => $row, row => $col)
 
@@ -462,7 +490,7 @@ sub moduleMethodCallAt {
 
     my ($module, $method) = $self->methodCallAt(row => $row, col => $col);
     $module && $method or return(undef);
-    $module =~ /[^\w:]/ and return(undef);   #only allow bareword modules
+    $module =~ /[^\w:]/ and return(undef); #only allow bareword modules
 
     wantarray() and return($module, $method);
     return("$module->$method");
